#!/bin/sh -x
#
# Build script for leafpad
. /etc/init.d/tc-functions
useBusybox

##############################################
## place these 2 files in /tmp dir
#
#leafpad_compile.sh (this script)
#leafpad-*(version).tar.xz
#
# then run this build script 
##############################################

name=leafpad
archive=$( echo leafpad-*z )
srcname=${archive%.tar*}
tmp=${archive#*-}
VER=${tmp%.tar*}
PKG=/tmp/leafpad_build/pkg
LOC=/tmp/leafpad_build/loc
PKGDIR=/tmp/leafpad_build
tceinstalled="/usr/local/tce.installed"
optional_path="/etc/sysconfig/tcedir/optional"
cd $optional_path
tce_path=$(realpath ${PWD%/*})

## load build deps
echo -e "\n\nFetching build dependencies... "

deps="compiletc.tcz \
Xorg-7.7-3d-dev.tcz \
gtk2-dev.tcz \
bash.tcz \
ncurses-dev.tcz \
cairo-dev.tcz \
gettext.tcz \
libiconv-dev.tcz \
intltool.tcz \
glib2-python.tcz \
libGL-dev.tcz"

for i in $deps ; do 

pkgname=${i%.tcz}

if [ ! -f ${tce_path}/optional/"$i" ]; then
	tce-load -wil "$pkgname"
	[ x$? != x0 ] && tce-load -wil "$pkgname"
	[ -f ${tceinstalled}/"$pkgname" ] || exit
elif [ ! -f ${tceinstalled}/"$pkgname" ]; then
	tce-load -i "$pkgname"
fi
done


sudo /sbin/ldconfig -v

sleep 1
#cleanup
[ -d /tmp/"$PKGDIR" ] && rm -rf /tmp/"$PKGDIR"

sleep 1.5

[ $PWD == /tmp ] || cd /tmp
tar xpvf $archive

cd /tmp/$srcname

## configure, make, make install
sleep 1
export CFLAGS="-march=i486 -mtune=i686 -Os -pipe" 
export CXXFLAGS="-march=i486 -mtune=i686 -Os -pipe -fno-exceptions -fno-rtti"

echo "${MAGENTA}run configure${NORMAL}"; sleep 0.5
./configure --prefix=/usr/local

echo "${MAGENTA}run make${NORMAL}"; sleep 0.5
make

cd ${PWD}/src && strip --strip-debug --strip-unneeded leafpad
cd ..

## fix permissions on install file
sudo chmod 775 ${PWD}/install-sh

echo "${MAGENTA}run make install${NORMAL}"; sleep 0.5
sudo make install DESTDIR=/tmp/leafpad_build/pkg

echo "${MAGENTA}create extension${NORMAL}"; sleep 0.5
[ "${PWD}" == /tmp ] || cd /tmp


sudo mkdir -p ${LOC}/usr/local/share
sudo cp -R ${PKG}/usr/local/share/locale ${LOC}/usr/local/share/locale

[ -d "$PKGDIR" ] || exit 4

sudo chown -R tc:staff /tmp/leafpad_build

find "$PKG" -type d -print0 | xargs -0 sudo chmod 775

find "$PKGDIR" -type f -print0 | xargs -0 sudo chmod 644

sudo chmod 775 ${PKG}/usr/local/bin/leafpad


## append to desktop file
cd /tmp/leafpad_build/pkg/usr/local/share/applications
if [ -f leafpad.desktop ]; then
  echo "Icon=leafpad" >> leafpad.desktop
  echo "X-FullPathIcon=/usr/local/share/pixmaps/leafpad.png" >> leafpad.desktop
else
  echo "${RED}missing leafpad.desktop file${NORMAL}"
  read -p "waiting.."
fi
cd "$PKGDIR"


#makesquash
tce-load -i squashfs-tools-4.x
if [ $? -ge 1 ]; then
	echo "${RED}squashfs-tools failed to load, exiting..${NORMAL}"
	exit 5
fi
cd "$PKGDIR"
mksquashfs pkg/ "$name".tcz -noappend
mksquashfs loc/ "$name"-locale.tcz -noappend

[ -f ${PKGDIR}/"$name".tcz ] && echo "${GREEN}done${NORMAL}"

